@@ -13,18 +13,22 @@ add=1/2, to="only0", drop00=FALSE, vtype="LS", var.names=c("yi","vi"), digits=4,
 
    if (!is.element(measure, c("RR","OR","PETO","RD","AS","PHI","YUQ","YUY","RTET", ### 2x2 table measures
                               "PBIT","OR2D","OR2DN","OR2DL",                       ### - transformations to SMD
+                              "MPRD","MPRR","MPOR","MPORC","MPPETO",               ### - measures for matched pairs data
                               "IRR","IRD","IRSD",                                  ### two-group person-time data measures
                               "MD","SMD","SMDH","ROM",                             ### two-group mean/SD measures
+                              "CVR","VR",                                          ### coefficient of variation ratio, variability ratio
                               "RPB","RBIS","D2OR","D2ORN","D2ORL",                 ### - transformations to r_PB, r_BIS, and log(OR)
                               "COR","UCOR","ZCOR",                                 ### correlations (raw and r-to-z transformed)
+                              "PCOR","ZPCOR","SPCOR",                              ### partial and semi-partial correlations
                               "PR","PLN","PLO","PAS","PFT",                        ### single proportions (and transformations thereof)
                               "IR","IRLN","IRS","IRFT",                            ### single-group person-time data (and transformations thereof)
-                              "MN","MC","SMCC","SMCR","SMCRH","ROMC",              ### raw/standardized mean change and log(ROM) for dependent samples
+                              "MN","MNLN","CVLN","SDLN",                           ### mean, log(mean), log(CV), log(SD)
+                              "MC","SMCC","SMCR","SMCRH","ROMC",                   ### raw/standardized mean change and log(ROM) for dependent samples
                               "ARAW","AHW","ABT")))                                ### alpha (and transformations thereof)
       stop("Unknown 'measure' specified.")
 
-   if (is.element(measure, c("MC","SMCC","SMCR","SMCRH","ROMC")))
-      stop("Formula interface (currently) not implemented for these outcome measures.")
+   if (is.element(measure, c("MPRD","MPRR","MPOR","MPORC","MPPETO","CVR","VR","PCOR","ZPCOR","SPCOR","CVLN","SDLN","MC","SMCC","SMCR","SMCRH","ROMC")))
+      stop("Formula interface (currently) not implemented for this outcome measure.")
 
    if (!requireNamespace("Formula", quietly=TRUE))
       stop("Please install the 'Formula' package to use the formula interface.")
@@ -330,7 +334,7 @@ add=1/2, to="only0", drop00=FALSE, vtype="LS", var.names=c("yi","vi"), digits=4,
 
    #########################################################################
 
-   if (is.element(measure, c("MN"))) {
+   if (is.element(measure, c("MN","MNLN"))) {
 
       if (is.null(weights))
          stop("Must specify the 'weights' argument.")
@@ -362,6 +366,11 @@ add=1/2, to="only0", drop00=FALSE, vtype="LS", var.names=c("yi","vi"), digits=4,
 
    #########################################################################
 
+   #if (is.element(measure, c("MPRD","MPRR","MPOR","MPORC","MPPETO"))) {
+   #}
+
+   #########################################################################
+
    if (is.element(measure, c("ARAW","AHW","ABT"))) {
 
       if (is.null(weights))
