@@ -3,7 +3,7 @@ xlim, alim, clim, ylim, at, steps=5, level=95,      refline=0, digits=2L, width,
 xlab, slab,            ilab, ilab.xpos, ilab.pos, subset,
 transf, atransf, targs, rows,
 efac=1, pch=15, psize, col, lty,
-cex, cex.lab, cex.axis, ...) {
+cex, cex.lab, cex.axis, annosym, ...) {
 
    #########################################################################
 
@@ -76,6 +76,11 @@ cex, cex.lab, cex.axis, ...) {
    if (length(efac) == 1L)
       efac <- rep(efac, 2)
 
+   if (missing(annosym))
+      annosym <- c(" [", ", ", "]")
+   if (length(annosym) != 3)
+      stop("Argument 'annosym' must be a vector of length 3.")
+
    #########################################################################
 
    ### digits[1] for annotations, digits[2] for x-axis labels
@@ -83,7 +88,7 @@ cex, cex.lab, cex.axis, ...) {
    if (length(digits) == 1L)
       digits <- c(digits,digits)
 
-   alpha <- ifelse(level > 1, (100-level)/100, 1-level)
+   level <- ifelse(level > 1, (100-level)/100, ifelse(level > .5, 1-level, level))
 
    yi <- x
 
@@ -99,7 +104,7 @@ cex, cex.lab, cex.axis, ...) {
       if (length(ci.lb) != length(ci.ub))
          stop("Length of 'ci.lb' and 'ci.ub' do not match.")
       if (missing(vi) && missing(sei)) {     ### vi/sei not specified, so calculate vi based on CI
-         vi <- ((ci.ub - ci.lb) / (2*qnorm(alpha/2, lower.tail=FALSE)))^2
+         vi <- ((ci.ub - ci.lb) / (2*qnorm(level/2, lower.tail=FALSE)))^2
       } else {
          if (missing(vi))                    ### vi not specified, but sei is, so set vi = sei^2
             vi <- sei^2
@@ -112,12 +117,12 @@ cex, cex.lab, cex.axis, ...) {
             stop("Must specify either 'vi', 'sei', or ('ci.lb', 'ci.ub') pairs.")
          } else {
             vi <- sei^2
-            ci.lb <- yi - qnorm(alpha/2, lower.tail=FALSE) * sei
-            ci.ub <- yi + qnorm(alpha/2, lower.tail=FALSE) * sei
+            ci.lb <- yi - qnorm(level/2, lower.tail=FALSE) * sei
+            ci.ub <- yi + qnorm(level/2, lower.tail=FALSE) * sei
          }
       } else {
-         ci.lb <- yi - qnorm(alpha/2, lower.tail=FALSE) * sqrt(vi)
-         ci.ub <- yi + qnorm(alpha/2, lower.tail=FALSE) * sqrt(vi)
+         ci.lb <- yi - qnorm(level/2, lower.tail=FALSE) * sqrt(vi)
+         ci.ub <- yi + qnorm(level/2, lower.tail=FALSE) * sqrt(vi)
       }
    }
 
@@ -539,14 +544,14 @@ cex, cex.lab, cex.axis, ...) {
             width <- rep(width, ncol(annotext))
       }
 
-      for (j in 1:ncol(annotext)) {
+      for (j in seq_len(ncol(annotext))) {
          annotext[,j] <- formatC(annotext[,j], width=width[j])
       }
 
       if (showweights) {
-         annotext <- cbind(annotext[,1], "%   ", annotext[,2], " [", annotext[,3], ", ", annotext[,4], "]")
+         annotext <- cbind(annotext[,1], "%   ", annotext[,2], annosym[1], annotext[,3], annosym[2], annotext[,4], annosym[3])
       } else {
-         annotext <- cbind(annotext[,1], " [", annotext[,2], ", ", annotext[,3], "]")
+         annotext <- cbind(annotext[,1], annosym[1], annotext[,2], annosym[2], annotext[,3], annosym[3])
       }
 
       annotext <- apply(annotext, 1, paste, collapse="")
