@@ -20,6 +20,21 @@ model.matrix.rma <- function(object, ...) {
    if (na.act == "na.fail" && any(!object$not.na))
       stop("Missing values in results.")
 
+   if (inherits(object, "rma.ls")) {
+
+      out <- list(location = out)
+
+      if (na.act == "na.omit")
+         out$scale <- object$Z
+
+      if (na.act == "na.exclude" || na.act == "na.pass")
+         out$scale <- object$Z.f
+
+      if (na.act == "na.fail" && any(!object$not.na))
+         stop("Missing values in results.")
+
+   }
+
    return(out)
 
 }
