@@ -18,13 +18,15 @@ print.robust.rma <- function(x, digits, signif.stars=getOption("show.signif.star
    }
    cat("\n")
 
-   if (x$p > 1) {
-      cat("Test of Moderators (coefficient(s) ", paste(x$btt, collapse=","),"): \n", sep="")
+   if (x$p > 1 && !is.na(x$QM)) {
+      cat("Test of Moderators (coefficient(s) ", .format.btt(x$btt),"): \n", sep="")
       cat("F(df1 = ", x$m, ", df2 = ", x$dfs, ") = ", formatC(x$QM, digits=digits, format="f"), ", p-val ", .pval(x$QMp, digits=digits, showeq=TRUE, sep=" "), "\n\n", sep="")
    }
 
-   res.table <- cbind(estimate=c(x$b), se=x$se, tval=x$tval, pval=x$pval, ci.lb=x$ci.lb, ci.ub=x$ci.ub)
-   rownames(res.table) <- rownames(x$b)
+   res.table <- cbind(estimate=c(x$beta), se=x$se, zval=x$zval, pval=x$pval, ci.lb=x$ci.lb, ci.ub=x$ci.ub)
+   rownames(res.table) <- rownames(x$beta)
+   if (is.element(x$test, c("knha","adhoc","t")))
+      colnames(res.table)[3] <- "tval"
    signif <- symnum(x$pval, corr=FALSE, na=FALSE, cutpoints=c(0, 0.001, 0.01, 0.05, 0.1, 1), symbols = c("***", "**", "*", ".", " "))
    if (signif.stars) {
       res.table <- cbind(formatC(res.table, digits=digits, format="f"), signif)
@@ -39,7 +41,8 @@ print.robust.rma <- function(x, digits, signif.stars=getOption("show.signif.star
 
    cat("Model Results:\n\n")
    if (x$int.only) {
-      print(res.table, quote=FALSE, right=TRUE)
+      .print.out(res.table)
+      #print(res.table, quote=FALSE, right=TRUE)
    } else {
       print(res.table, quote=FALSE, right=TRUE, print.gap=2)
    }
