@@ -22,14 +22,19 @@ ranef.rma.uni <- function(object, level, digits, transf, targs, ...) {
    if (missing(targs))
       targs <- NULL
 
-   alpha <- ifelse(level > 1, (100-level)/100, 1-level)
+   level <- ifelse(level > 1, (100-level)/100, ifelse(level > .5, 1-level, level))
 
    if (is.element(x$test, c("knha","adhoc","t"))) {
-      crit <- qt(alpha/2, df=x$dfs, lower.tail=FALSE)
+      crit <- qt(level/2, df=x$dfs, lower.tail=FALSE)
    } else {
-      crit <- qnorm(alpha/2, lower.tail=FALSE)
+      crit <- qnorm(level/2, lower.tail=FALSE)
    }
 
+   ### TODO: check computations for user-defined weights
+
+   if (!is.null(x$weights) || !x$weighted)
+      stop("Extraction of random effects for models with non-standard weights not currently implemented.")
+
    #########################################################################
 
    pred  <- rep(NA_real_, x$k.f)
@@ -38,8 +43,6 @@ ranef.rma.uni <- function(object, level, digits, transf, targs, ...) {
    ### see Appendix in: Raudenbush, S. W., & Bryk, A. S. (1985). Empirical
    ### Bayes meta-analysis. Journal of Educational Statistics, 10(2), 75-98
 
-   ### TODO: is this still correct if user has specified arbitrary weights?
-
    li <- x$tau2 / (x$tau2 + x$vi.f)
 
    for (i in seq_len(x$k.f)[x$not.na]) { ### note: skipping NA cases
@@ -48,7 +51,7 @@ ranef.rma.uni <- function(object, level, digits, transf, targs, ...) {
          pred[i]  <- 0
          vpred[i] <- 0
       } else {
-         pred[i]  <- li[i] * (x$yi.f[i] - Xi %*% x$b)
+         pred[i]  <- li[i] * (x$yi.f[i] - Xi %*% x$beta)
          vpred[i] <- li[i] * x$vi.f[i] + li[i]^2 * Xi %*% tcrossprod(x$vb,Xi)
       }
    }
