@@ -15,9 +15,13 @@ rstandard.rma.peto <- function(model, digits, ...) {
 
    #########################################################################
 
-   ei <- c(x$yi.f - x$b)
+   ei <- c(x$yi.f - x$beta)
+
    ei[abs(ei) < 100 * .Machine$double.eps] <- 0
    #ei[abs(ei) < 100 * .Machine$double.eps * median(abs(ei), na.rm=TRUE)] <- 0 ### see lm.influence
+
+   ### note: these are like Pearson (or semi-standardized) residuals
+
    sei <- sqrt(x$vi.f)
    zi <- ei / sei
 
