@@ -1,4 +1,4 @@
-rstudent.rma.mh <- function(model, digits, ...) {
+rstudent.rma.mh <- function(model, digits, progbar=FALSE, ...) {
 
    if (!inherits(model, "rma.mh"))
       stop("Argument 'model' must be an object of class \"rma.mh\".")
@@ -20,7 +20,16 @@ rstudent.rma.mh <- function(model, digits, ...) {
 
    ### note: skipping NA tables
 
-   for (i in seq_len(x$k.f)[x$not.na]) {
+   if (progbar)
+      pbar <- txtProgressBar(min=0, max=x$k.f, style=3)
+
+   for (i in seq_len(x$k.f)) {
+
+      if (progbar)
+         setTxtProgressBar(pbar, i)
+
+      if (!x$not.na[i])
+         next
 
       if (is.element(x$measure, c("RR","OR","RD"))) {
          res <- try(suppressWarnings(rma.mh(ai=x$ai.f, bi=x$bi.f, ci=x$ci.f, di=x$di.f, measure=x$measure, add=x$add, to=x$to, drop00=x$drop00, correct=x$correct, subset=-i)), silent=TRUE)
@@ -31,11 +40,14 @@ rstudent.rma.mh <- function(model, digits, ...) {
       if (inherits(res, "try-error"))
          next
 
-      delpred[i]  <- res$b
+      delpred[i]  <- res$beta
       vdelpred[i] <- res$vb
 
    }
 
+   if (progbar)
+      close(pbar)
+
    delresid <- x$yi.f - delpred
    delresid[abs(delresid) < 100 * .Machine$double.eps] <- 0
    #delresid[abs(delresid) < 100 * .Machine$double.eps * median(abs(delresid), na.rm=TRUE)] <- 0 ### see lm.influence
