@@ -5,16 +5,23 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
 
    if (!is.element(measure, c("RR","OR","PETO","RD","AS","PHI","YUQ","YUY","RTET", ### 2x2 table measures
                               "PBIT","OR2D","OR2DN","OR2DL",                       ### - transformations to SMD
+                              "MPRD","MPRR","MPOR","MPORC","MPPETO",               ### - measures for matched pairs data
                               "IRR","IRD","IRSD",                                  ### two-group person-time data measures
                               "MD","SMD","SMDH","ROM",                             ### two-group mean/SD measures
+                              "CVR","VR",                                          ### coefficient of variation ratio, variability ratio
                               "RPB","RBIS","D2OR","D2ORN","D2ORL",                 ### - transformations to r_PB, r_BIS, and log(OR)
                               "COR","UCOR","ZCOR",                                 ### correlations (raw and r-to-z transformed)
+                              "PCOR","ZPCOR","SPCOR",                              ### partial and semi-partial correlations
                               "PR","PLN","PLO","PAS","PFT",                        ### single proportions (and transformations thereof)
                               "IR","IRLN","IRS","IRFT",                            ### single-group person-time data (and transformations thereof)
-                              "MN","MC","SMCC","SMCR","SMCRH","ROMC",              ### raw/standardized mean change and log(ROM) for dependent samples
+                              "MN","MNLN","CVLN","SDLN",                           ### mean, log(mean), log(CV), log(SD)
+                              "MC","SMCC","SMCR","SMCRH","ROMC",                   ### raw/standardized mean change and log(ROM) for dependent samples
                               "ARAW","AHW","ABT")))                                ### alpha (and transformations thereof)
       stop("Unknown 'measure' specified.")
 
+   if (is.element(measure, c("CVR","VR","PCOR","ZPCOR","SPCOR","CVLN","SDLN")))
+      stop("Function (currently) not implemented for this outcome measure.")
+
    na.act <- getOption("na.action")
 
    if (!is.element(na.act, c("na.omit", "na.exclude", "na.fail", "na.pass")))
@@ -35,9 +42,8 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
    if (is.null(data)) {
       data <- sys.frame(sys.parent())
    } else {
-      if (!is.data.frame(data)) {
+      if (!is.data.frame(data))
          data <- data.frame(data)
-      }
    }
 
    mf <- match.call()
@@ -53,7 +59,7 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
    #########################################################################
    #########################################################################
 
-   if (is.element(measure, c("RR","OR","RD","AS","PETO","PHI","YUQ","YUY","RTET","PBIT","OR2D","OR2DN","OR2DL"))) {
+   if (is.element(measure, c("RR","OR","RD","AS","PETO","PHI","YUQ","YUY","RTET","PBIT","OR2D","OR2DN","OR2DL","MPRD","MPRR","MPOR","MPORC","MPPETO"))) {
 
       mf.ai   <- mf[[match("ai",  names(mf))]]
       mf.bi   <- mf[[match("bi",  names(mf))]]
@@ -247,7 +253,7 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
       n1i     <- eval(mf.n1i,  data, enclos=sys.frame(sys.parent()))
       n2i     <- eval(mf.n2i,  data, enclos=sys.frame(sys.parent()))
 
-      k <- length(m1i) ### number of outcomes before subsetting
+      k <- length(n1i) ### number of outcomes before subsetting
 
       if (!is.null(subset)) {
          m1i  <- m1i[subset]
@@ -443,7 +449,7 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
 
    #########################################################################
 
-   if (is.element(measure, c("MN"))) {
+   if (is.element(measure, c("MN","MNLN"))) {
 
       mf.mi   <- mf[[match("mi",  names(mf))]]
       mf.sdi  <- mf[[match("sdi", names(mf))]]
@@ -452,7 +458,7 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
       sdi     <- eval(mf.sdi, data, enclos=sys.frame(sys.parent()))
       ni      <- eval(mf.ni,  data, enclos=sys.frame(sys.parent()))
 
-      k <- length(mi) ### number of outcomes before subsetting
+      k <- length(ni) ### number of outcomes before subsetting
 
       if (!is.null(subset)) {
          mi  <- mi[subset]
@@ -472,6 +478,9 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
       if (any(ni < 0, na.rm=TRUE))
          stop("One or more sample sizes are negative.")
 
+      if (is.element(measure, c("MNLN","CVLN")) && any(mi < 0, na.rm=TRUE))
+         stop("One or more means are negative.")
+
       ni.u <- ni ### unadjusted total sample sizes
 
   }
@@ -594,7 +603,7 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
       ### check if study labels are unique; if not, make them unique
 
       if (anyDuplicated(slab))
-         slab <- make.unique(as.character(slab)) ### make.unique() only works with character vectors
+         slab <- .make.unique(slab)
 
       if (length(slab) != k)
          stop("Study labels not of same length as data.")
@@ -617,11 +626,11 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
 
       ### check for NAs in table data and act accordingly
 
-      aibicidi.na <- is.na(ai) | is.na(bi) | is.na(ci) | is.na(di)
+      has.na <- is.na(ai) | is.na(bi) | is.na(ci) | is.na(di)
 
-      if (any(aibicidi.na)) {
+      if (any(has.na)) {
 
-         not.na <- !aibicidi.na
+         not.na <- !has.na
 
          if (na.act == "na.omit") {
             ai   <- ai[not.na]
@@ -673,7 +682,7 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
          dat[,3] <- factor(dat[,3])
 
          if (!no.data && append)
-            dat <- data.frame(data[rep(1:k, each=4),], dat)
+            dat <- data.frame(data[rep(seq_len(k), each=4),], dat)
 
       } else {
 
@@ -699,7 +708,195 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
          dat[,2] <- factor(dat[,2])
 
          if (!no.data && append)
-            dat <- data.frame(data[rep(1:k, each=2),], dat)
+            dat <- data.frame(data[rep(seq_len(k), each=2),], dat)
+
+      }
+
+   }
+
+   #########################################################################
+
+   if (is.element(measure, c("MPRD","MPRR","MPOR"))) {
+
+      ### check for NAs in table data and act accordingly
+
+      has.na <- is.na(ai) | is.na(bi) | is.na(ci) | is.na(di)
+
+      if (any(has.na)) {
+
+         not.na <- !has.na
+
+         if (na.act == "na.omit") {
+            ai   <- ai[not.na]
+            bi   <- bi[not.na]
+            ci   <- ci[not.na]
+            di   <- di[not.na]
+            slab <- slab[not.na]
+            if (!no.data)
+               data <- data[not.na,]
+            warning("Tables with NAs omitted.")
+         }
+
+         if (na.act == "na.fail")
+            stop("Missing values in tables.")
+
+      }
+
+      k <- length(ai)
+
+      ### at least one study left?
+
+      if (k < 1)
+         stop("Processing terminated since k = 0.")
+
+      ### create long format dataset
+
+      if (vlong) {
+
+         ### create very long format dataset
+
+         dat <- matrix(NA, nrow=4*k, ncol=4)
+
+         dat[,1] <- rep(slab, each=4)
+         dat[,2] <- rep(c(1,1,2,2), k)
+         dat[,3] <- rep(c(1,2,1,2), k)
+         dat[,4] <- c(rbind(ai+bi,ci+di,ai+ci,bi+di))
+
+         if (missing(var.names)) {
+            colnames(dat) <- c("study", "time", "outcome", "freq")
+         } else {
+            if (length(var.names) != 4)
+               stop("Variable names not of length 4.")
+            colnames(dat) <- var.names
+         }
+
+         dat <- data.frame(dat)
+         dat[,1] <- factor(dat[,1])
+         dat[,2] <- factor(dat[,2])
+         dat[,3] <- factor(dat[,3])
+
+         if (!no.data && append)
+            dat <- data.frame(data[rep(seq_len(k), each=4),], dat)
+
+      } else {
+
+         ### create regular long format dataset
+
+         dat <- matrix(NA, nrow=2*k, ncol=4)
+
+         dat[,1] <- rep(slab, each=2)
+         dat[,2] <- rep(c(1,2), k)
+         dat[,3] <- c(rbind(ai+bi,ai+ci))
+         dat[,4] <- c(rbind(ci+di,bi+di))
+
+         if (missing(var.names)) {
+            colnames(dat) <- c("study", "time", "out1", "out2")
+         } else {
+            if (length(var.names) != 4)
+               stop("Variable names not of length 4.")
+            colnames(dat) <- var.names
+         }
+
+         dat <- data.frame(dat)
+         dat[,1] <- factor(dat[,1])
+         dat[,2] <- factor(dat[,2])
+
+         if (!no.data && append)
+            dat <- data.frame(data[rep(seq_len(k), each=2),], dat)
+
+      }
+
+   }
+
+   #########################################################################
+
+   if (is.element(measure, c("MPORC","MPPETO"))) {
+
+      ### check for NAs in table data and act accordingly
+
+      has.na <- is.na(ai) | is.na(bi) | is.na(ci) | is.na(di)
+
+      if (any(has.na)) {
+
+         not.na <- !has.na
+
+         if (na.act == "na.omit") {
+            ai   <- ai[not.na]
+            bi   <- bi[not.na]
+            ci   <- ci[not.na]
+            di   <- di[not.na]
+            slab <- slab[not.na]
+            if (!no.data)
+               data <- data[not.na,]
+            warning("Tables with NAs omitted.")
+         }
+
+         if (na.act == "na.fail")
+            stop("Missing values in tables.")
+
+      }
+
+      k <- length(ai)
+
+      ### at least one study left?
+
+      if (k < 1)
+         stop("Processing terminated since k = 0.")
+
+      ### create long format dataset
+
+      if (vlong) {
+
+         ### create very long format dataset
+
+         dat <- matrix(NA, nrow=4*k, ncol=4)
+
+         dat[,1] <- rep(slab, each=4)
+         dat[,2] <- rep(c(1,1,2,2), k)
+         dat[,3] <- rep(c(1,2,1,2), k)
+         dat[,4] <- c(rbind(ai,bi,ci,di))
+
+         if (missing(var.names)) {
+            colnames(dat) <- c("study", "out.time1", "out.time2", "freq")
+         } else {
+            if (length(var.names) != 4)
+               stop("Variable names not of length 4.")
+            colnames(dat) <- var.names
+         }
+
+         dat <- data.frame(dat)
+         dat[,1] <- factor(dat[,1])
+         dat[,2] <- factor(dat[,2])
+         dat[,3] <- factor(dat[,3])
+
+         if (!no.data && append)
+            dat <- data.frame(data[rep(seq_len(k), each=4),], dat)
+
+      } else {
+
+         ### create regular long format dataset
+
+         dat <- matrix(NA, nrow=2*k, ncol=4)
+
+         dat[,1] <- rep(slab, each=2)
+         dat[,2] <- rep(c(1,2), k)
+         dat[,3] <- c(rbind(ai,ci))
+         dat[,4] <- c(rbind(bi,di))
+
+         if (missing(var.names)) {
+            colnames(dat) <- c("study", "out.time1", "out1.time2", "out2.time2")
+         } else {
+            if (length(var.names) != 4)
+               stop("Variable names not of length 4.")
+            colnames(dat) <- var.names
+         }
+
+         dat <- data.frame(dat)
+         dat[,1] <- factor(dat[,1])
+         dat[,2] <- factor(dat[,2])
+
+         if (!no.data && append)
+            dat <- data.frame(data[rep(seq_len(k), each=2),], dat)
 
       }
 
@@ -711,11 +908,11 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
 
       ### check for NAs in table data and act accordingly
 
-      x1ix2it1it2i.na <- is.na(x1i) | is.na(x2i) | is.na(t1i) | is.na(t2i)
+      has.na <- is.na(x1i) | is.na(x2i) | is.na(t1i) | is.na(t2i)
 
-      if (any(x1ix2it1it2i.na)) {
+      if (any(has.na)) {
 
-         not.na <- !x1ix2it1it2i.na
+         not.na <- !has.na
 
          if (na.act == "na.omit") {
             x1i  <- x1i[not.na]
@@ -762,7 +959,7 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
       dat[,2] <- factor(dat[,2])
 
       if (!no.data && append)
-         dat <- data.frame(data[rep(1:k, each=2),], dat)
+         dat <- data.frame(data[rep(seq_len(k), each=2),], dat)
 
    }
 
@@ -772,11 +969,11 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
 
       ### check for NAs in table data and act accordingly
 
-      m1im2isd1isd2in1in2i.na <- is.na(m1i) | is.na(m2i) | is.na(sd1i) | is.na(sd2i) | is.na(n1i) | is.na(n2i)
+      has.na <- is.na(m1i) | is.na(m2i) | is.na(sd1i) | is.na(sd2i) | is.na(n1i) | is.na(n2i)
 
-      if (any(m1im2isd1isd2in1in2i.na)) {
+      if (any(has.na)) {
 
-         not.na <- !m1im2isd1isd2in1in2i.na
+         not.na <- !has.na
 
          if (na.act == "na.omit") {
             m1i  <- m1i[not.na]
@@ -826,7 +1023,7 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
       dat[,2] <- factor(dat[,2])
 
       if (!no.data && append)
-         dat <- data.frame(data[rep(1:k, each=2),], dat)
+         dat <- data.frame(data[rep(seq_len(k), each=2),], dat)
 
    }
 
@@ -836,11 +1033,11 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
 
       ### check for NAs in table data and act accordingly
 
-      rini.na <- is.na(ri) | is.na(ni)
+      has.na <- is.na(ri) | is.na(ni)
 
-      if (any(rini.na)) {
+      if (any(has.na)) {
 
-         not.na <- !rini.na
+         not.na <- !has.na
 
          if (na.act == "na.omit") {
             ri   <- ri[not.na]
@@ -893,11 +1090,11 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
 
       ### check for NAs in table data and act accordingly
 
-      ximi.na <- is.na(xi) | is.na(mi)
+      has.na <- is.na(xi) | is.na(mi)
 
-      if (any(ximi.na)) {
+      if (any(has.na)) {
 
-         not.na <- !ximi.na
+         not.na <- !has.na
 
          if (na.act == "na.omit") {
             xi   <- xi[not.na]
@@ -945,7 +1142,7 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
          dat[,2] <- factor(dat[,2])
 
          if (!no.data && append)
-            dat <- data.frame(data[rep(1:k, each=2),], dat)
+            dat <- data.frame(data[rep(seq_len(k), each=2),], dat)
 
       } else {
 
@@ -980,11 +1177,11 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
 
       ### check for NAs in table data and act accordingly
 
-      xiti.na <- is.na(xi) | is.na(ti)
+      has.na <- is.na(xi) | is.na(ti)
 
-      if (any(xiti.na)) {
+      if (any(has.na)) {
 
-         not.na <- !xiti.na
+         not.na <- !has.na
 
          if (na.act == "na.omit") {
             xi   <- xi[not.na]
@@ -1033,15 +1230,15 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
 
    #########################################################################
 
-   if (is.element(measure, c("MN"))) {
+   if (is.element(measure, c("MN","MNLN"))) {
 
       ### check for NAs in table data and act accordingly
 
-      misdini.na <- is.na(mi) | is.na(sdi) | is.na(ni)
+      has.na <- is.na(mi) | is.na(sdi) | is.na(ni)
 
-      if (any(misdini.na)) {
+      if (any(has.na)) {
 
-         not.na <- !misdini.na
+         not.na <- !has.na
 
          if (na.act == "na.omit") {
             mi   <- mi[not.na]
@@ -1058,7 +1255,7 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
 
       }
 
-      k <- length(mi)
+      k <- length(ni)
 
       ### at least one study left?
 
@@ -1097,14 +1294,14 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
       ### check for NAs in table data and act accordingly
 
       if (is.element(measure, c("MC","SMCC","SMCRH","ROMC"))) {
-         m1im2isdiniri.na <- is.na(m1i) | is.na(m2i) | is.na(sd1i) | is.na(sd2i) | is.na(ni) | is.na(ri)
+         has.na <- is.na(m1i) | is.na(m2i) | is.na(sd1i) | is.na(sd2i) | is.na(ni) | is.na(ri)
       } else {
-         m1im2isdiniri.na <- is.na(m1i) | is.na(m2i) | is.na(sd1i) | is.na(ni) | is.na(ri)
+         has.na <- is.na(m1i) | is.na(m2i) | is.na(sd1i) | is.na(ni) | is.na(ri)
       }
 
-      if (any(m1im2isdiniri.na)) {
+      if (any(has.na)) {
 
-         not.na <- !m1im2isdiniri.na
+         not.na <- !has.na
 
          if (na.act == "na.omit") {
             m1i  <- m1i[not.na]
@@ -1195,11 +1392,11 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
 
       ### check for NAs in table data and act accordingly
 
-      aimini.na <- is.na(ai) | is.na(mi) | is.na(ni)
+      has.na <- is.na(ai) | is.na(mi) | is.na(ni)
 
-      if (any(aimini.na)) {
+      if (any(has.na)) {
 
-         not.na <- !aimini.na
+         not.na <- !has.na
 
          if (na.act == "na.omit") {
             ai   <- ai[not.na]
@@ -1250,7 +1447,7 @@ data, slab, subset, add=1/2, to="none", drop00=FALSE, vlong=FALSE, append=TRUE,
 
    #########################################################################
 
-   rownames(dat) <- 1:nrow(dat)
+   rownames(dat) <- seq_len(nrow(dat))
    return(dat)
 
 }
