@@ -2,7 +2,7 @@
 
 ### see also: http://www.metafor-project.org/doku.php/analyses:berkey1998
 
-context("Checking analysis example berkey1998")
+context("Checking analysis example: berkey1998")
 
 ### load data
 dat <- get(data(dat.berkey1998, package="metafor"))
@@ -14,6 +14,7 @@ test_that("results are correct for the multiple outcomes random-effects model.",
 
    ### multiple outcomes random-effects model (with ML estimation)
    res <- rma.mv(yi, V, mods = ~ outcome - 1, random = ~ outcome | trial, struct="UN", data=dat, method="ML")
+   out <- capture.output(print(res)) ### so that print.rma.mv() is run (at least once)
 
    ### (results for this model not given in paper)
    expect_equivalent(round(coef(res),3), c(-0.338, 0.345))
@@ -54,6 +55,7 @@ test_that("results are correct when testing var-cov structures against each othe
    res1 <- rma.mv(yi, V, mods = ~ outcome - 1, random = ~ outcome | trial, struct="UN", data=dat, method="ML")
    res0 <- rma.mv(yi, V, mods = ~ outcome - 1, random = ~ outcome | trial, struct="CS", data=dat, method="ML")
    tmp <- anova(res0, res1)
+   out <- capture.output(print(tmp)) ### so that print.anova.rma() is run (at least once)
 
    ### (results for this not given in paper)
    expect_equivalent(round(tmp$pval,4), 0.2597)
