@@ -2,7 +2,7 @@
 
 ### see also: http://www.metafor-project.org/doku.php/analyses:rothman2008
 
-context("Checking analysis example rothman2008")
+context("Checking analysis example: rothman2008")
 
 ############################################################################
 
@@ -25,6 +25,22 @@ test_that("the to.table() function works.", {
 
 })
 
+test_that("the to.long() function works.", {
+
+   tmp <- to.long(ai=ai, bi=bi, ci=ci, di=di, data=dat, measure="OR", slab=as.character(age))
+
+   expected <- structure(list(age = structure(c(1L, 1L, 2L, 2L), .Label = c("Age <55", "Age 55+"), class = "factor"),
+                         ai = c(8, 8, 22, 22), bi = c(98, 98, 76, 76), ci = c(5, 5, 16, 16), di = c(115, 115, 69, 69),
+                         study = structure(c(1L, 1L, 2L, 2L), .Label = c("Age <55", "Age 55+"), class = "factor"),
+                         group = structure(c(1L, 2L, 1L, 2L), .Label = c("1", "2"), class = "factor"),
+                         out1 = structure(c(4L, 3L, 2L, 1L), .Label = c("16", "22", "5", "8"), class = "factor"),
+                         out2 = structure(c(4L, 1L, 3L, 2L), .Label = c("115", "69", "76", "98"), class = "factor")),
+                         .Names = c("age", "ai", "bi", "ci", "di", "study", "group", "out1", "out2"), row.names = c(NA, 4L), class = "data.frame")
+
+   expect_equivalent(tmp, expected)
+
+})
+
 test_that("the stratum-specific and crude risk differences are computed correctly.", {
 
    ### stratum-specific risk differences
@@ -73,6 +89,7 @@ test_that("results are correct for Mantel-Haenszel method.", {
 
    ### Mantel-Haenszel method with risk differences
    res <- rma.mh(ai=ai, bi=bi, ci=ci, di=di, data=dat, measure="RD", digits=3, level=90)
+   out <- capture.output(print(res)) ### so that print.rma.mh() is used
 
    expect_equivalent(round(coef(res),3),  0.035)
    expect_equivalent(round(res$ci.lb,3), -0.018)
@@ -82,6 +99,7 @@ test_that("results are correct for Mantel-Haenszel method.", {
 
    ### Mantel-Haenszel method with risk ratios
    res <- rma.mh(ai=ai, bi=bi, ci=ci, di=di, data=dat, measure="RR", digits=2, level=90)
+   out <- capture.output(print(res)) ### so that print.rma.mh() is used
 
    expect_equivalent(round(coef(res),2),  0.28)
    expect_equivalent(round(res$ci.lb,2), -0.14)
@@ -94,6 +112,7 @@ test_that("results are correct for Mantel-Haenszel method.", {
 
    ### Mantel-Haenszel method with odds ratios
    res <- rma.mh(ai=ai, bi=bi, ci=ci, di=di, data=dat, measure="OR", correct=FALSE, digits=2, level=90)
+   out <- capture.output(print(res)) ### so that print.rma.mh() is used
 
    expect_equivalent(round(coef(res),2),  0.34)
    expect_equivalent(round(res$ci.lb,2), -0.17)
@@ -110,21 +129,23 @@ test_that("results are correct for Mantel-Haenszel method.", {
    tmp <- c(round(confint(res, transf=exp)$fixed, 2))
    expect_equivalent(tmp, c(1.40, 0.84, 2.34))
 
+   skip_on_cran()
+
    ### conditional MLE of the odds ratio
    res <- rma.glmm(ai=ai, bi=bi, ci=ci, di=di, data=dat, measure="OR", model="CM.EL", method="FE")
 
    expect_equivalent(round(coef(res),3),  0.338)
    expect_equivalent(round(res$ci.lb,3), -0.271)
    expect_equivalent(round(res$ci.ub,3),  0.947)
-   expect_equivalent(round(res$QE.Wld,3),  0.346)
-   expect_equivalent(round(res$QEp.Wld,3), 0.556)
+   expect_equivalent(round(res$QE.Wld,2),  0.35) ### rounded a bit more heavily, so 32-bit and 64-bit versions give same result
+   expect_equivalent(round(res$QEp.Wld,2), 0.56) ### rounded a bit more heavily, so OS X version gives same result
    expect_equivalent(round(res$QE.LRT,3),  0.350)
    expect_equivalent(round(res$QEp.LRT,3), 0.554)
 
    tmp <- predict(res, transf=exp)
    expect_equivalent(round(tmp$pred,3),  1.402)
    expect_equivalent(round(tmp$ci.lb,3), 0.763)
-   expect_equivalent(round(tmp$ci.ub,3), 2.578)
+   expect_equivalent(round(tmp$ci.ub,2), 2.58) ### rounded a bit more heavily, so 32-bit and 64-bit versions give same result
 
 })
 
@@ -149,6 +170,25 @@ test_that("the to.table() function works.", {
 
 })
 
+test_that("the to.long() function works.", {
+
+   tmp <- to.long(x1i=x1i, x2i=x2i, t1i=t1i, t2i=t2i, data=dat, measure="IRR", slab=as.character(age))
+
+   expected <- structure(list(age = structure(c(1L, 1L, 2L, 2L, 3L, 3L, 4L, 4L, 5L, 5L), .Label = c("35-44", "45-54", "55-64", "65-74", "75-84"), class = "factor"),
+                         x1i = c(32, 32, 104, 104, 206, 206, 186, 186, 102, 102),
+                         t1i = c(5.2407, 5.2407, 4.3248, 4.3248, 2.8612, 2.8612, 1.2663, 1.2663, 0.5317, 0.5317),
+                         x2i = c(2, 2, 12, 12, 28, 28, 28, 28, 31, 31),
+                         t2i = c(1.879, 1.879, 1.0673, 1.0673, 0.571, 0.571, 0.2585, 0.2585, 0.1462, 0.1462),
+                         study = structure(c(1L, 1L, 2L, 2L, 3L, 3L, 4L, 4L, 5L, 5L), .Label = c("35-44", "45-54", "55-64", "65-74", "75-84"), class = "factor"),
+                         group = structure(c(1L, 2L, 1L, 2L, 1L, 2L, 1L, 2L, 1L, 2L), .Label = c("1", "2"), class = "factor"),
+                         events = structure(c(9L, 5L, 2L, 3L, 6L, 7L, 4L, 7L, 1L, 8L), .Label = c("102", "104", "12", "186", "2", "206", "28", "31", "32"), class = "factor"),
+                         ptime = structure(c(10L, 7L, 9L, 5L, 8L, 4L, 6L, 2L, 3L, 1L), .Label = c("0.1462", "0.2585", "0.5317", "0.571", "1.0673", "1.2663", "1.879", "2.8612", "4.3248", "5.2407"), class = "factor")),
+                         .Names = c("age", "x1i", "t1i", "x2i", "t2i", "study", "group", "events", "ptime"), row.names = c(NA, 10L), class = "data.frame")
+
+   expect_equivalent(tmp, expected)
+
+})
+
 test_that("the stratum-specific and crude rate differences are computed correctly.", {
 
    ### stratum-specific rate differences
@@ -224,6 +264,8 @@ test_that("results are correct for Mantel-Haenszel method.", {
    expect_equivalent(round(res$MH,3), 11.016)
    expect_equivalent(round(res$MHp,3), 0.001)
 
+   skip_on_cran()
+
    ### unconditional MLE of the rate ratio
    res <- rma.glmm(x1i=x1i, x2i=x2i, t1i=t1i, t2i=t2i, data=dat, measure="IRR", digits=2, level=90, model="UM.FS", method="FE")
 
@@ -279,6 +321,22 @@ test_that("the to.table() function works.", {
 
 })
 
+test_that("the to.long() function works.", {
+
+   tmp <- to.long(ai=ai, bi=bi, ci=ci, di=di, data=dat, measure="OR", slab=as.character(age))
+
+   expected <- structure(list(age = structure(c(1L, 1L, 2L, 2L), .Label = c("<35", "35+"), class = "factor"),
+                         ai = c(3, 3, 1, 1), bi = c(9, 9, 3, 3), ci = c(104, 104, 5, 5), di = c(1059, 1059, 86, 86),
+                         study = structure(c(1L, 1L, 2L, 2L), .Label = c("<35", "35+"), class = "factor"),
+                         group = structure(c(1L, 2L, 1L, 2L), .Label = c("1", "2"), class = "factor"),
+                         out1 = structure(c(3L, 2L, 1L, 4L), .Label = c("1", "104", "3", "5"), class = "factor"),
+                         out2 = structure(c(4L, 1L, 2L, 3L), .Label = c("1059", "3", "86", "9"), class = "factor")),
+                         .Names = c("age", "ai", "bi", "ci", "di", "study", "group", "out1", "out2"), row.names = c(NA, 4L), class = "data.frame")
+
+   expect_equivalent(tmp, expected)
+
+})
+
 test_that("results are correct for Mantel-Haenszel method.", {
 
    ### Mantel-Haenszel method with odds ratios
@@ -299,6 +357,8 @@ test_that("results are correct for Mantel-Haenszel method.", {
    tmp <- c(round(confint(res, transf=exp)$fixed, 2))
    expect_equivalent(tmp, c(3.78, 1.43, 10.00))
 
+   skip_on_cran()
+
    ### unconditional MLE of the odds ratio
    res <- rma.glmm(ai=ai, bi=bi, ci=ci, di=di, data=dat, measure="OR", digits=2, level=90, model="UM.FS", method="FE")
 
@@ -319,17 +379,17 @@ test_that("results are correct for Mantel-Haenszel method.", {
    res <- rma.glmm(ai=ai, bi=bi, ci=ci, di=di, data=dat, measure="OR", digits=2, level=90, model="CM.EL", method="FE")
 
    expect_equivalent(round(coef(res),3), 1.326)
-   expect_equivalent(round(res$ci.lb,3), 0.356)
+   expect_equivalent(round(res$ci.lb,2), 0.36) ### rounded a bit more heavily, so 32-bit and 64-bit versions give same result
    expect_equivalent(round(res$ci.ub,3), 2.296)
-   expect_equivalent(round(res$QE.Wld,3),  0.123)
-   expect_equivalent(round(res$QEp.Wld,3), 0.726)
+   expect_equivalent(round(res$QE.Wld,2),  0.13) ### rounded a bit more heavily, so 32-bit and 64-bit versions give same result
+   expect_equivalent(round(res$QEp.Wld,2), 0.72) ### rounded a bit more heavily, so 32-bit and 64-bit versions give same result
    expect_equivalent(round(res$QE.LRT,3),  0.119)
    expect_equivalent(round(res$QEp.LRT,3), 0.730)
 
    tmp <- predict(res, transf=exp)
    expect_equivalent(round(tmp$pred,3),  3.765)
-   expect_equivalent(round(tmp$ci.lb,3), 1.427)
-   expect_equivalent(round(tmp$ci.ub,3), 9.932)
+   expect_equivalent(round(tmp$ci.lb,2), 1.43) ### rounded a bit more heavily, so 32-bit and 64-bit versions give same result
+   expect_equal(tmp$ci.ub, 9.936, tolerance=.001) ### need to use tolerance so 32-bit and 64-bit versions give same result
 
 })
 
